@@ -380,7 +380,10 @@ class TrackMeHandlerSplkBlocklistWrite_v2(trackme_rest_handler.RESTHandler):
                     keys_list = resp_dict["keys_list"]
                     # Handle as a CSV list of keys if not a list already
                     if not isinstance(keys_list, list):
-                        keys_list = keys_list.split(",")
+                        keys_list = [x.strip() for x in keys_list.split(",") if x.strip()]
+                    else:
+                        # Filter out empty strings from existing list
+                        keys_list = [x.strip() if isinstance(x, str) else x for x in keys_list if (x.strip() if isinstance(x, str) else bool(x))]
                 except Exception as e:
                     return {
                         "payload": "keys_list is required, please provide a valid keys_list",
@@ -633,8 +636,9 @@ class TrackMeHandlerSplkBlocklistWrite_v2(trackme_rest_handler.RESTHandler):
 
                 try:
                     records_list = resp_dict["records_list"]
-                    # Handle as a CSV list of keys
-                    records_list = json.loads(records_list)
+                    # Handle as an object list if needed
+                    if not isinstance(records_list, list):
+                        records_list = json.loads(records_list)
                 except Exception as e:
                     return {
                         "payload": "records_list is required, please provide a valid records_list",
